@@ -51,7 +51,7 @@ UNESCAPED_SEQUENCES = {
 }
 
 
-def _annotate_with_type_lambda(data_type: exp.DataType.Type) -> t.Callable[[TypeAnnotator, E], E]:
+def annotate_with_type_lambda(data_type: exp.DataType.Type) -> t.Callable[[TypeAnnotator, E], E]:
     return lambda self, e: self._annotate_with_type(e, data_type)
 
 
@@ -683,15 +683,15 @@ class Dialect(metaclass=_Dialect):
             exp.ParseJSON,
         },
         exp.DataType.Type.TIME: {
+            exp.CurrentTime,
             exp.Time,
+            exp.TimeAdd,
+            exp.TimeSub,
         },
         exp.DataType.Type.TIMESTAMP: {
-            exp.CurrentTime,
             exp.CurrentTimestamp,
             exp.StrToTime,
-            exp.TimeAdd,
             exp.TimeStrToTime,
-            exp.TimeSub,
             exp.TimestampAdd,
             exp.TimestampSub,
             exp.UnixToTime,
@@ -733,7 +733,7 @@ class Dialect(metaclass=_Dialect):
             for expr_type in subclasses(exp.__name__, exp.Binary)
         },
         **{
-            expr_type: _annotate_with_type_lambda(data_type)
+            expr_type: annotate_with_type_lambda(data_type)
             for data_type, expressions in TYPE_TO_EXPRESSIONS.items()
             for expr_type in expressions
         },
@@ -1025,6 +1025,12 @@ class Dialect(metaclass=_Dialect):
     def version(self) -> Version:
         return Version(self.settings.get("version", None))
 
+    def generate_values_aliases(self, expression: exp.Values) -> t.List[exp.Identifier]:
+        return [
+            exp.to_identifier(f"_col_{i}")
+            for i, _ in enumerate(expression.expressions[0].expressions)
+        ]
+
 
 DialectType = t.Union[str, Dialect, t.Type[Dialect], None]
 
@@ -1232,15 +1238,20 @@ def build_date_delta(
     exp_class: t.Type[E],
     unit_mapping: t.Optional[t.Dict[str, str]] = None,
     default_unit: t.Optional[str] = "DAY",
+    supports_timezone: bool = False,
 ) -> t.Callable[[t.List], E]:
     def _builder(args: t.List) -> E:
-        unit_based = len(args) == 3
+        unit_based = len(args) >= 3
+        has_timezone = len(args) == 4
         this = args[2] if unit_based else seq_get(args, 0)
         unit = None
         if unit_based or default_unit:
             unit = args[0] if unit_based else exp.Literal.string(default_unit)
             unit = exp.var(unit_mapping.get(unit.name.lower(), unit.name)) if unit_mapping else unit
-        return exp_class(this=this, expression=seq_get(args, 1), unit=unit)
+        expression = exp_class(this=this, expression=seq_get(args, 1), unit=unit)
+        if supports_timezone and has_timezone:
+            expression.set("zone", args[-1])
+        return expression
 
     return _builder
 
@@ -1297,7 +1308,9 @@ def no_timestamp_sql(self: Generator, expression: exp.Timestamp) -> str:
     if not zone:
         from sqlglot.optimizer.annotate_types import annotate_types
 
-        target_type = annotate_types(expression).type or exp.DataType.Type.TIMESTAMP
+        target_type = (
+            annotate_types(expression, dialect=self.dialect).type or exp.DataType.Type.TIMESTAMP
+        )
         return self.sql(exp.cast(expression.this, target_type))
     if zone.name.lower() in TIMEZONES:
         return self.sql(
@@ -1864,7 +1877,7 @@ def build_timetostr_or_tochar(args: t.List, dialect: Dialect) -> exp.TimeToStr |
     if this and not this.type:
         from sqlglot.optimizer.annotate_types import annotate_types
 
-        annotate_types(this)
+        annotate_types(this, dialect=dialect)
         if this.is_type(*exp.DataType.TEMPORAL_TYPES):
             dialect_name = dialect.__class__.__name__.lower()
             return build_formatted_time(exp.TimeToStr, dialect_name, default=True)(args)
