@@ -17,6 +17,8 @@ class TestTSQL(Validator):
         # tsql allows .. which means use the default schema
         self.validate_identity("SELECT * FROM a..b")
 
+        self.validate_identity("GO").assert_is(exp.Command)
+        self.validate_identity("SELECT go").selects[0].assert_is(exp.Column)
         self.validate_identity("CREATE view a.b.c", "CREATE VIEW b.c")
         self.validate_identity("DROP view a.b.c", "DROP VIEW b.c")
         self.validate_identity("ROUND(x, 1, 0)")
@@ -559,6 +561,14 @@ class TestTSQL(Validator):
             with self.assertRaises(ParseError, msg=f"When running '{query}'"):
                 self.parse_one(query)
 
+        self.validate_all(
+            "SELECT col FROM t OPTION(LABEL = 'foo')",
+            write={
+                "tsql": "SELECT col FROM t OPTION(LABEL = 'foo')",
+                "databricks": UnsupportedError,
+            },
+        )
+
     def test_types(self):
         self.validate_identity("CAST(x AS XML)")
         self.validate_identity("CAST(x AS UNIQUEIDENTIFIER)")
